export default {
    "index": 20,
    "lineNumber": 2,
    "column": 1,
    "message": "Unexpected token"
};